Welcome to pympress’s documentation! — Pympress developer documentation

# Welcome to pympress’s documentation!

## Contents

- What is Pympress?
- Installing
  - Using pip (requires python)
  - Binary install (currently only for windows)
- Usage
  - Opening a file
  - Functionalities
  - Command line arguments
- Dependencies
  - On linux platforms
  - On macOS
  - On windows
- Contributing
  - Translations
- Pympress package
  - Modules

## Indices and tables

- Index

- Module Index